summaryrefslogtreecommitdiffstats
path: root/korn/boxcontainer.h
diff options
context:
space:
mode:
Diffstat (limited to 'korn/boxcontainer.h')
-rw-r--r--korn/boxcontainer.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/korn/boxcontainer.h b/korn/boxcontainer.h
index 765d28b18..e5f5a8f4c 100644
--- a/korn/boxcontainer.h
+++ b/korn/boxcontainer.h
@@ -25,7 +25,7 @@ class BoxContainerItem;
template< class T > class TQPtrList;
-class KConfig;
+class TDEConfig;
/**
* This class is the base for all BoxContainers. A BoxContainer is a place
@@ -48,18 +48,18 @@ public:
~BoxContainer();
/**
* This method reads the config from a certain KConfig instance.
*
* @param config The KConfig-instance to read the config from.
*/
- void readConfig( KConfig* config );
+ void readConfig( TDEConfig* config );
/**
* This method writes the config to a certain KConfig instance.
*
* @param config The KConfig-instance to write the config to.
*/
- void writeConfig( KConfig *config );
+ void writeConfig( TDEConfig *config );
/**
* Shows all childs and itself
@@ -48,18 +48,18 @@ public:
~BoxContainer();
/**
- * This method reads the config from a certain KConfig instance.
+ * This method reads the config from a certain TDEConfig instance.
*
@@ -48,18 +48,18 @@ public:
*
- * @param config The KConfig-instance to read the config from.
+ * @param config The TDEConfig-instance to read the config from.
*/
@@ -48,18 +48,18 @@ public:
/**
- * This method writes the config to a certain KConfig instance.
+ * This method writes the config to a certain TDEConfig instance.
*
@@ -48,18 +48,18 @@ public:
*
- * @param config The KConfig-instance to write the config to.
+ * @param config The TDEConfig-instance to write the config to.
*/